==> DateTime-Locale-1.16.tar.gz: DateTime-Locale-1.16/share/ebu.pl <==
{
  am_pm_abbreviated => [
    "KI",
    "UT"
  ],
  available_formats => {
    E => "ccc",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' y"
  },
  code => "ebu",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Tat",
    "Ine",
    "Tan",
    "Arm",
    "Maa",
    "NMM",
    "Kma"
  ],
  day_format_narrow => [
    "N",
    "N",
    "N",
    "A",
    "M",
    "N",
    "K"
  ],
  day_format_wide => [
    "Njumatatu",
    "Njumaine",
    "Njumatano",
    "Aramithi",
    "Njumaa",
    "NJumamothii",
    "Kiumia"
  ],
  day_stand_alone_abbreviated => [
    "Tat",
    "Ine",
    "Tan",
    "Arm",
    "Maa",
    "NMM",
    "Kma"
  ],
  day_stand_alone_narrow => [
    "N",
    "N",
    "N",
    "A",
    "M",
    "N",
    "K"
  ],
  day_stand_alone_wide => [
    "Njumatatu",
    "Njumaine",
    "Njumatano",
    "Aramithi",
    "Njumaa",
    "NJumamothii",
    "Kiumia"
  ],
  era_abbreviated => [
    "MK",
    "TK"
  ],
  era_narrow => [
    "MK",
    "TK"
  ],
  era_wide => [
    "Mbere ya Kristo",
    "Thutha wa Kristo"
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Embu",
  month_format_abbreviated => [
    "Mbe",
    "Kai",
    "Kat",
    "Kan",
    "Gat",
    "Gan",
    "Mug",
    "Knn",
    "Ken",
    "Iku",
    "Imw",
    "Igi"
  ],
  month_format_narrow => [
    "M",
    "K",
    "K",
    "K",
    "G",
    "G",
    "M",
    "K",
    "K",
    "I",
    "I",
    "I"
  ],
  month_format_wide => [
    "Mweri wa mbere",
    "Mweri wa ka\N{U+0129}ri",
    "Mweri wa kathat\N{U+0169}",
    "Mweri wa kana",
    "Mweri wa gatano",
    "Mweri wa gatantat\N{U+0169}",
    "Mweri wa m\N{U+0169}gwanja",
    "Mweri wa kanana",
    "Mweri wa kenda",
    "Mweri wa ik\N{U+0169}mi",
    "Mweri wa ik\N{U+0169}mi na \N{U+0169}mwe",
    "Mweri wa ik\N{U+0169}mi na Ka\N{U+0129}r\N{U+0129}"
  ],
  month_stand_alone_abbreviated => [
    "Mbe",
    "Kai",
    "Kat",
    "Kan",
    "Gat",
    "Gan",
    "Mug",
    "Knn",
    "Ken",
    "Iku",
    "Imw",
    "Igi"
  ],
  month_stand_alone_narrow => [
    "M",
    "K",
    "K",
    "K",
    "G",
    "G",
    "M",
    "K",
    "K",
    "I",
    "I",
    "I"
  ],
  month_stand_alone_wide => [
    "Mweri wa mbere",
    "Mweri wa ka\N{U+0129}ri",
    "Mweri wa kathat\N{U+0169}",
    "Mweri wa kana",
    "Mweri wa gatano",
    "Mweri wa gatantat\N{U+0169}",
    "Mweri wa m\N{U+0169}gwanja",
    "Mweri wa kanana",
    "Mweri wa kenda",
    "Mweri wa ik\N{U+0169}mi",
    "Mweri wa ik\N{U+0169}mi na \N{U+0169}mwe",
    "Mweri wa ik\N{U+0169}mi na Ka\N{U+0129}r\N{U+0129}"
  ],
  name => "Embu",
  native_language => "K\N{U+0129}embu",
  native_name => "K\N{U+0129}embu",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4"
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_format_wide => [
    "Kuota ya mbere",
    "Kuota ya Ka\N{U+0129}r\N{U+0129}",
    "Kuota ya kathatu",
    "Kuota ya kana"
  ],
  quarter_stand_alone_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4"
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_stand_alone_wide => [
    "Kuota ya mbere",
    "Kuota ya Ka\N{U+0129}r\N{U+0129}",
    "Kuota ya kathatu",
    "Kuota ya kana"
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 31
}

==> DateTime-Locale-1.19.tar.gz: DateTime-Locale-1.19/share/ebu.pl <==
{
  am_pm_abbreviated => [
    "KI",
    "UT",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "ebu",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Tat",
    "Ine",
    "Tan",
    "Arm",
    "Maa",
    "NMM",
    "Kma",
  ],
  day_format_narrow => [
    "N",
    "N",
    "N",
    "A",
    "M",
    "N",
    "K",
  ],
  day_format_wide => [
    "Njumatatu",
    "Njumaine",
    "Njumatano",
    "Aramithi",
    "Njumaa",
    "NJumamothii",
    "Kiumia",
  ],
  day_stand_alone_abbreviated => [
    "Tat",
    "Ine",
    "Tan",
    "Arm",
    "Maa",
    "NMM",
    "Kma",
  ],
  day_stand_alone_narrow => [
    "N",
    "N",
    "N",
    "A",
    "M",
    "N",
    "K",
  ],
  day_stand_alone_wide => [
    "Njumatatu",
    "Njumaine",
    "Njumatano",
    "Aramithi",
    "Njumaa",
    "NJumamothii",
    "Kiumia",
  ],
  era_abbreviated => [
    "MK",
    "TK",
  ],
  era_narrow => [
    "MK",
    "TK",
  ],
  era_wide => [
    "Mbere ya Kristo",
    "Thutha wa Kristo",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Embu",
  month_format_abbreviated => [
    "Mbe",
    "Kai",
    "Kat",
    "Kan",
    "Gat",
    "Gan",
    "Mug",
    "Knn",
    "Ken",
    "Iku",
    "Imw",
    "Igi",
  ],
  month_format_narrow => [
    "M",
    "K",
    "K",
    "K",
    "G",
    "G",
    "M",
    "K",
    "K",
    "I",
    "I",
    "I",
  ],
  month_format_wide => [
    "Mweri wa mbere",
    "Mweri wa ka\N{U+0129}ri",
    "Mweri wa kathat\N{U+0169}",
    "Mweri wa kana",
    "Mweri wa gatano",
    "Mweri wa gatantat\N{U+0169}",
    "Mweri wa m\N{U+0169}gwanja",
    "Mweri wa kanana",
    "Mweri wa kenda",
    "Mweri wa ik\N{U+0169}mi",
    "Mweri wa ik\N{U+0169}mi na \N{U+0169}mwe",
    "Mweri wa ik\N{U+0169}mi na Ka\N{U+0129}r\N{U+0129}",
  ],
  month_stand_alone_abbreviated => [
    "Mbe",
    "Kai",
    "Kat",
    "Kan",
    "Gat",
    "Gan",
    "Mug",
    "Knn",
    "Ken",
    "Iku",
    "Imw",
    "Igi",
  ],
  month_stand_alone_narrow => [
    "M",
    "K",
    "K",
    "K",
    "G",
    "G",
    "M",
    "K",
    "K",
    "I",
    "I",
    "I",
  ],
  month_stand_alone_wide => [
    "Mweri wa mbere",
    "Mweri wa ka\N{U+0129}ri",
    "Mweri wa kathat\N{U+0169}",
    "Mweri wa kana",
    "Mweri wa gatano",
    "Mweri wa gatantat\N{U+0169}",
    "Mweri wa m\N{U+0169}gwanja",
    "Mweri wa kanana",
    "Mweri wa kenda",
    "Mweri wa ik\N{U+0169}mi",
    "Mweri wa ik\N{U+0169}mi na \N{U+0169}mwe",
    "Mweri wa ik\N{U+0169}mi na Ka\N{U+0129}r\N{U+0129}",
  ],
  name => "Embu",
  native_language => "K\N{U+0129}embu",
  native_name => "K\N{U+0129}embu",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Kuota ya mbere",
    "Kuota ya Ka\N{U+0129}r\N{U+0129}",
    "Kuota ya kathatu",
    "Kuota ya kana",
  ],
  quarter_stand_alone_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Kuota ya mbere",
    "Kuota ya Ka\N{U+0129}r\N{U+0129}",
    "Kuota ya kathatu",
    "Kuota ya kana",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 33,
}
